<?php

namespace app\admin\service\order;

use app\model\Appointment;
use support\Db;
use support\Request;
use function _PHPStan_cc8d35ffb\RingCentral\Psr7\str;

class AppointmentService
{
    public static function select(Request $request)
    {
        $page = $request->get('page');
        $pageSize = $request->get('pageSize');
        $id = $request->get('id', '');
        $mobile = $request->get('mobile', '');


        $rows = Db::table('appointment')
            ->leftJoin('member', 'member.member_id', '=', 'appointment.join_appointment_member_id')
            ->leftJoin('goods', 'goods.goods_id', '=', 'appointment.join_appointment_goods_id')
            ->leftJoin('order', 'order.order_id', '=', 'appointment.join_appointment_order_id')
            ->leftJoin('member_benefit', 'member_benefit.member_benefit_id', '=', 'appointment.join_appointment_member_benefit_id')
            ->leftJoin('goods_sku', 'goods_sku.goods_sku_id', '=', 'appointment.join_appointment_goods_sku_id')
            ->when($id != '', function ($query) use ($id) {
                $query->where('appointment.appointment_id', 'like', '%' . $id . '%');
            })->when($mobile != '', function ($query) use ($mobile) {
                $query->where('member.member_mobile', 'like', '%' . $mobile . '%');
            });

        $total = $rows->count('member.member_id');
        $rows = $rows->select('member.member_mobile', 'appointment.*', 'goods.goods_name', 'goods.goods_cover',
            'order.order_name', 'goods_sku.goods_sku_specs_json', 'order.order_amount_total', 'order.order_amount_pay',
            'order.order_category', 'order.order_status_system', 'order.order_status_payment', 'order.order_status_storage',
            'order.order_addtimes',
            'member_benefit.member_benefit_name'
        )
            ->orderBy('appointment.appointment_addtimes', 'desc')
            ->forPage($page, $pageSize)
            ->get();

        foreach ($rows as &$row) {
            $row->goods_cover = getenv('STORAGE_DOMAIN') . $row->goods_cover;
            $row->goods_sku_specs_json = !empty($row->goods_sku_specs_json) ? json_decode($row->goods_sku_specs_json, true) : [];
            $row->appointment_addtimes = date('Y-m-d H:i:s', $row->appointment_addtimes);
        }

        return json_success('', compact('rows', 'page', 'pageSize', 'total'));
    }

    public static function confirm($id)
    {
        $appointment = Appointment::where('appointment_id', $id)->where('appointment_status', 'WAITING')->first();
        if (!$appointment) {
            return json_fail('数据异常');
        }

        try {
            $appointment->appointment_status = 'PENDING';
            $appointment->save();

            return json_success('操作成功');
        } catch (\Exception $e) {
            dump($e->getMessage());
            return json_fail("操作失败");
        }
    }

    public static function update(Request $request)
    {
        $appointmentId = $request->post('appointment_id');
        if (!Appointment::where('appointment_id', $appointmentId)->exists()) {
            return json_fail("数据不存在");
        }
        $params = $request->post();
        try {
            $data = [
                'appointment_status'=>$params['appointment_status'],
                'appointment_datetime'=>$params['appointment_datetime'] ? date('Y-m-d H:i:s',strtotime($params['appointment_datetime'])) : null,
                'appointment_apply_datetime'=>$params['appointment_apply_datetime'] ? date('Y-m-d H:i:s',strtotime($params['appointment_apply_datetime'])) : null,
                'appointment_doing_datetime'=>$params['appointment_doing_datetime'] ? date('Y-m-d H:i:s',strtotime($params['appointment_doing_datetime'])) : null,
                'appointment_done_datetime'=>$params['appointment_done_datetime'] ? date('Y-m-d H:i:s',strtotime($params['appointment_done_datetime'])) : null,
                'appointment_cancel_datetime'=>$params['appointment_cancel_datetime'] ? date('Y-m-d H:i:s',strtotime($params['appointment_cancel_datetime'])) : null,
                'appointment_remark'=>$params['appointment_remark'] ?? '',
            ];

            Appointment::where('appointment_id', $appointmentId)->update($data);

            return json_success("数据更新成功");
        }catch (\Exception $e){
            dump($e->getMessage());
            return json_fail("数据更新失败");
        }
    }
}